@@ -24,7 +24,9 @@ class LargeImageMixinBase:
         str : The local file path to pass to large_image
 
         """
-        raise NotImplementedError('You must implement `get_path` on your viewset.')
+        raise NotImplementedError(
+            'You must implement `get_path` on your viewset.'
+        )  # pragma: no cover
 
     def get_query_param(self, request: Request, key: str, default: Optional[Any] = '') -> str:
         return request.query_params.get(key, str(default))
@@ -59,13 +61,18 @@ class LargeImageMixinBase:
                 if not utilities.param_nully(nodata):
                     style['nodata'] = nodata
                 scheme = self.get_query_param(request, 'scheme')
-                if not utilities.param_nully:
+                if not utilities.param_nully(scheme):
                     style['scheme'] = scheme
         return style
 
-    def open_tile_source(self, path, *args, **kwargs) -> FileTileSource:
+    def open_tile_source(
+        self, request: Request, path: Union[str, pathlib.Path], **kwargs
+    ) -> FileTileSource:
         """Override to open with a specific large-image source."""
-        return tilesource.get_tilesource_from_path(path, *args, **kwargs)
+        source = self.get_query_param(request, 'source')
+        # error: "get_tilesource_from_path" gets multiple values for keyword
+        # argument "source" Found 1 error in 1 file (checked 15 source files)
+        return tilesource.get_tilesource_from_path(path, source=source, **kwargs)  # type: ignore
 
     def open_image(
         self,
@@ -89,7 +96,7 @@ class LargeImageMixinBase:
                 kwargs['style'] = _style
         if projection:
             kwargs['projection'] = projection
-        return self.open_tile_source(path, **kwargs)
+        return self.open_tile_source(request, path, **kwargs)
 
     def get_tile_source(
         self,
